#
# spec file for package ypbind
#
# Copyright (c) 2018, 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           ypbind
Version:        2.7.2
Release:        2.14
Summary:        NIS client daemon
License:        GPL-2.0-only
Group:          Productivity/Networking/NIS
URL:            https://github.com/thkukuk/ypbind-mt/
Source:         %{name}-mt-%{version}.tar.xz
Source2:        ypbind.service
Source3:        ypbind-systemd-pre
Source4:        ypbind.conf
Source5:        ypbind.default
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libnsl) >= 1.0.1
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libtirpc) >= 1.0.1
Requires:       libnss_nis2
Requires:       rpcbind
Requires:       yp-tools
Requires(post): /usr/bin/grep

%description
This package provides the ypbind daemon. The ypbind daemon binds NIS
clients to an NIS domain and searches a new NIS server if the old one
goes down.

Ypbind must be running on any machines which are running NIS client
programs.

%prep
%setup -q -n ypbind-mt-%{version}

%build
%configure --disable-dbus-nm
make  %{?_smp_mflags}

%install
%make_install
# Install default/ypbind
install -D -m 644 %{SOURCE5}  %{buildroot}%{_prefix}/etc/default/ypbind
# Create dummy yp.conf
mkdir -p %{buildroot}%{_sysconfdir}
touch %{buildroot}%{_sysconfdir}/yp.conf
# Create filelist with translatins
%find_lang ypbind-mt
# Install systemd stuff
install -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/ypbind.service
mkdir -p %{buildroot}%{_libexecdir}/ypbind
install -m 755 %{SOURCE3} %{buildroot}%{_libexecdir}/ypbind/ypbind-systemd-pre
# create symlink for rcypbind
ln -s /sbin/service %{buildroot}%{_sbindir}/rcypbind
mkdir -p %{buildroot}%{_prefix}/lib/tmpfiles.d
install -m 644 %{SOURCE4} %{buildroot}%{_prefix}/lib/tmpfiles.d/

%pre
%service_add_pre ypbind.service

%post
%service_add_post ypbind.service
%tmpfiles_create ypbind.conf
if [ -f /etc/sysconfig/ypbind ]; then
    # migrate variables from sysconfig to default
    grep ^YPBIND_OPTIONS= /etc/sysconfig/ypbind > /etc/default/ypbind
    mv /etc/sysconfig/ypbind /etc/sysconfig/ypbind.rpmsave
fi

%preun
%service_del_preun ypbind.service

%postun
%service_del_postun ypbind.service
if [ "$1" = "0" ]; then
   test -d %{_localstatedir}/yp/binding && rm -rf %{_localstatedir}/yp/binding ||:
fi

%files -f ypbind-mt.lang
%license COPYING
%doc NEWS README
%ghost %config(noreplace) %{_sysconfdir}/yp.conf
%{_prefix}/etc/default/
%{_mandir}/man5/yp.conf.5%{ext_man}
%{_mandir}/man8/ypbind.8%{ext_man}
%{_sbindir}/ypbind
%{_sbindir}/rcypbind
%{_unitdir}/ypbind.service
%dir %{_libexecdir}/ypbind
%{_libexecdir}/ypbind/*
%{_prefix}/lib/tmpfiles.d/ypbind.conf

%changelog
* Sat Aug 29 2020 Thorsten Kukuk <kukuk@suse.com>
- Use /usr/etc/default and /etc/default instead of sysconfig
- Cleanup ypbind-systemd-pre
* Sat Aug 29 2020 Thorsten Kukuk <kukuk@suse.com>
- Use /usr/libexec in ypbind.service
* Fri Jan 31 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.7.2
  - change /run/yp.conf to /run/netconfig/yp.conf
* Thu Jan 30 2020 Thorsten Kukuk <kukuk@suse.com>
- ypbind-systemd-pre: fix path of second yp.conf
* Wed Jan 29 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.7.1
  - try /run/yp.conf if /etc/yp.conf does not exist
  - strip down /etc/sysconfig/ypbind to a generic option list only
* Tue Jul 30 2019 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.6.1
  - check if libc provides already gettid()
* Fri Jul 26 2019 matthias.gerstner@suse.com
- removal of SuSEfirewall2 service, since SuSEfirewall2 has been replaced by
  firewalld, see [1].
  [1]: https://lists.opensuse.org/opensuse-factory/2019-01/msg00490.html
* Mon Mar 25 2019 lnussel@suse.de
- ypbind needs yp.conf to be present. So wait for network to be
  online in case it's created by DHCP (boo#1129587)
* Fri Feb 22 2019 Franck Bui <fbui@suse.com>
- Drop use of $FIRST_ARG in .spec
  The use of $FIRST_ARG was probably required because of the
  %%service_* rpm macros were playing tricks with the shell positional
  parameters. This is bad practice and error prones so let's assume
  that no macros should do that anymore and hence it's safe to assume
  that positional parameters remains unchanged after any rpm macro
  call.
* Tue Jan 22 2019 kukuk@suse.de
- Update to version 2.6
  - fix crash on reload [bsc#1114640]
* Mon Jun  4 2018 kukuk@suse.de
- Update to version 2.5
  - enhance yp.conf manual page
* Fri Feb 23 2018 kukuk@suse.com
- Use %%license instead of %%doc [bsc#1082318]
* Wed Nov 22 2017 kukuk@suse.de
- Prepare for new fillup location
- Remove check for transactional-update, done in systemd macros now
* Wed Nov  8 2017 kukuk@suse.de
- Fix cleanup of /var/yp/binding dirctory on de-installation
* Wed Nov  8 2017 kukuk@suse.de
- Use tmpfiles.d for /var/yp hierachy in preparation of read-only
  root filesystem and transactional-updates
* Fri Oct  6 2017 kukuk@suse.de
- Require libnss_nis2, else NIS accounts are never visible
* Thu Aug 10 2017 kukuk@suse.de
- Adjust list of to be installed docu files
* Mon Feb 20 2017 mpluskal@suse.com
- Some packaging cleanup:
  * Use macro for configure and make install
  * Build in parallel
  * Drop no longer needed buildroot
  * Run spec-cleaner
* Wed Feb  8 2017 kukuk@suse.de
- Remove wrong insserv requires and support for old init scripts
* Wed Jul  6 2016 fbui@suse.com
- Replace pkgconfig(libsystemd-daemon) with pkgconfig(libsystemd)
  Nowadays pkgconfig(libsystemd) replaces all libsystemd-* libs, which
  are obsolete.
* Mon Jun 20 2016 kukuk@suse.de
- Remove syslog.target from ypbind.service file [bsc#983938]
* Wed Mar  2 2016 kukuk@suse.de
- Update to ypbind-2.4
  - fix broadcast option
* Fri Feb 26 2016 kukuk@suse.de
- Don't abort if no NIS server could be found in a defined time.
* Mon Feb 15 2016 kukuk@suse.de
- Update to ypbind-2.3
  - use libnsl/libtirpc instead of libnis
* Thu Dec  4 2014 kukuk@suse.de
- Update to ypbind-2.2
  - fix handling of not reacheable NIS server
  - check that the port of the NIS server hasn't changed
* Mon Dec  1 2014 kukuk@suse.de
- Update to ypbind-2.1
  - remove references to obsolete dbus feature
  - use shorter timeouts
* Mon Nov  3 2014 kukuk@suse.de
- Update to ypbind-2.0
  - final release with IPv6 support
* Sat Nov  1 2014 kukuk@suse.de
- Update to ypbind-1-99.5
  - disable workaround which could lead to a crash
* Tue Oct 28 2014 kukuk@suse.de
- Update to ypbind-1.99.4
  - ypbind protocol v3 fully implemented
* Fri Oct 24 2014 kukuk@suse.de
- Update to ypbind-1.99.3
  - build against libnis/ti-rpc
  - register with ypbind protocol version 3, too
* Tue Oct 21 2014 kukuk@suse.de
- Update to ypbind-1.99.2
  - add check for localhost/IPv6
* Mon Oct 20 2014 kukuk@suse.de
- Update to ypbind-1.99.1
  - register with IPv6 addresses, too.
* Mon Oct 20 2014 kukuk@suse.de
- Update to ypbind-1.38
  - use pkg-config for systemd in configure script
* Tue May 27 2014 kukuk@suse.de
- Adjust for systemd changes
* Tue Mar 25 2014 werner@suse.de
- Avoid bad timings and timeouts if a shutdown was done by a remote
  user via su and with autofs based home directory
* Thu Mar  6 2014 kukuk@suse.de
- Update to ypbind-1.37.2
  - fix detection of sd_notify()
- ypbind-systemd-post: remove wrong leftover code from init script
* Thu Feb 20 2014 kukuk@suse.de
- Add ExecReload to ypbind.service for wicked
* Fri Feb 14 2014 kukuk@suse.de
- Remove finally sysv init script
* Fri Jul 26 2013 tchvatal@suse.com
- Fix download url to point to real place.
* Fri Jul 26 2013 tchvatal@suse.com
- Provide back rcypbind as symlink to /sbin/service
* Wed Apr 10 2013 kukuk@suse.de
- Update to ypbind-1.37.1
  - revert sysconfig/ypbind changes
- Fix the systemd script mess, create new ypbind-systemd-exec script
- Revert removal of init script, breaks package update in running
  system.
* Tue Apr  9 2013 kukuk@suse.de
- Update to ypbind-1.37
  - simply sysconfig/ypbind
  - new -rebind_interval option
  - direct systemd support
* Thu Apr  4 2013 crrodriguez@opensuse.org
- portmap --> rpcbind
- remove sysvinit support
* Fri Oct 12 2012 fcrozat@suse.com
- Set NIS domainname if not set already before starting ypbind
  (bnc#716746).
* Tue Jul 10 2012 trenn@suse.de
- Add native systemd support (ypbind.service and friends).
  bnc#769405
* Mon Mar 26 2012 kukuk@suse.de
- Update to ypbind-1.35 (bug fix release)
* Sat Feb 25 2012 coolo@suse.com
- buildrequire libxml2-tools on factory
* Fri Jun  3 2011 jeffm@suse.de
- Update NetworkManager interface to use new NM_STATE_* (bnc#698030).
* Mon May  2 2011 kukuk@suse.de
- Update to 1.33: Better error checking
* Wed Jul  7 2010 kukuk@suse.de
- Update to 1.32: Fix problems with dbus
* Mon Nov 30 2009 kukuk@suse.de
- Update to 1.31: Fix -broadcast option
* Thu Nov 19 2009 kukuk@suse.de
- Update to 1.30: adjust to current network manager
* Fri Jun 19 2009 kukuk@suse.de
- Update to 1.29.91: Minor bug fixes
* Wed May 20 2009 kukuk@suse.de
- Update to 1.29.90: Rewrite of server search logic.
* Mon May 18 2009 kukuk@suse.de
- Update to 1.23.1: Fix last patch if NM support is disabled
* Mon Mar 30 2009 kukuk@suse.de
- Update to 1.23: Improvements in NetworkManager support
* Thu Aug 28 2008 kukuk@suse.de
- Update to 1.22:
  - Merge Patches
  - Only write binding file if it has really changed
* Thu Aug 14 2008 kukuk@suse.de
- Adjust init script to new policy
* Thu Apr 17 2008 schwab@suse.de
- Fix start script.
* Tue Apr 15 2008 kukuk@suse.de
- Update to 1.21:
  - Add -verbose option
  - Fix typo in option handling
* Wed Mar 26 2008 mkoenig@suse.de
- add support for rpcbind [fate#300607]
* Wed May  2 2007 kukuk@suse.de
- Add SuSEfirewall2 service data [Fate #300687/bnc #251659]
* Thu Mar  8 2007 kukuk@suse.de
- Update to 1.20.5:
  - Fix array access above array bounds [bnc #247312].
* Mon Feb 19 2007 kukuk@suse.de
- Update to 1.20.4:
  - merge dbus shared connection fix
  - add swedish translation
  - get ride of NetworkManager dependency
* Fri Oct 20 2006 thoenig@suse.de
- Add patch ypbind-do-not-close-shared-connection-thoenig-01.patch:
  Do not close shared connection to the D-Bus system bus.
* Wed Oct  4 2006 kukuk@suse.de
- Update to 1.20.2 (Assume we are online if no DBUS is running)
* Fri Sep 15 2006 kukuk@suse.de
- Update to 1.20.1 (fix SIGPIPE ignore)
- Remove obsolete obsoletes.
* Wed Sep 13 2006 kukuk@suse.de
- Update to official 1.20 release (includes -no-dbus option)
* Tue Aug 29 2006 kukuk@suse.de
- Fix synchronisation issue with threads [#202388]
* Thu Aug 17 2006 kukuk@suse.de
- Add DBUS/NetworkManager support to ypbind
- Remove obsolete documentation
* Fri May 26 2006 schwab@suse.de
- Don't strip binaries.
* Wed May 17 2006 seife@suse.de
- Add README.NetworkManager [#175935]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jul  5 2005 kukuk@suse.de
- Update to 1.19.1 (fix crash in debug code)
* Fri Jul  1 2005 kukuk@suse.de
- Update to 1.19 (Make error handling more robust)
* Fri Oct 15 2004 kukuk@suse.de
- Update to 1.18 (Add -ping-interval option) [Bug #47278]
* Thu Apr 29 2004 kukuk@suse.de
- Update to 1.17.3 (fix SLP URL parsing)
* Sat Feb 14 2004 kukuk@suse.de
- Update to 1.17.2 (SLP URL changed)
* Fri Feb 13 2004 kukuk@suse.de
- Update to 1.17 (SLP support added)
* Mon Jan 12 2004 adrian@suse.de
- build as user
* Fri Jan  9 2004 kukuk@suse.de
- Update to 1.15 (-local-only/-p bug fixes)
* Tue Aug 26 2003 kukuk@suse.de
- Update to 1.14 (ypset bug fixes)
* Fri Aug 15 2003 kukuk@suse.de
- Add ServiceRestart tag to sysconfig [Bug #28964]
* Tue Jul 29 2003 kukuk@suse.de
- Use new stop_on_removal/restart_on_upate macros
* Mon Jul 28 2003 kukuk@suse.de
- Fix postun/preun scripts
* Mon Jul 28 2003 kukuk@suse.de
- Don't remove binding files on update
- Stop daemon on uninstall
- Restart daemon on update
* Tue Jun 10 2003 kukuk@suse.de
- Update to ypbind-mt 1.13
- Use %%find_lang
* Tue May 13 2003 kukuk@suse.de
- Add defattr
* Fri Jan 17 2003 kukuk@suse.de
- Add sysconfig meta data [Bug #22706]
- Check every second if NIS server is online (make booting faster)
* Thu Aug  1 2002 kukuk@suse.de
- Add PreRequires for fillup and insserv
* Thu Jul 18 2002 kukuk@suse.de
- init script: ypserv is should-start, not required.
* Mon May 27 2002 kukuk@suse.de
- Update to ypbind 1.12 (Add broadcast option to yp.conf)
* Fri Apr  5 2002 kukuk@suse.de
- Update to ypbind 1.11 (fixes deadlock if one host is not
  resolveable), add more sysconfig options (local-only, broadcast)
* Sat Feb 16 2002 kukuk@suse.de
- Add /etc/yp.conf as ghost config file
* Fri Jan 25 2002 kukuk@suse.de
- init script:
  * redirect error messages of ypdomainname to /dev/null
  * Check, if /etc/defaultdomain contains a domainname
* Wed Jan 23 2002 kukuk@suse.de
- Source correct sysconfig file in init script
* Fri Jan 11 2002 kukuk@suse.de
- Remove all YP variables except the options for ypbind from
  rc.config
- Remove SuSEconfig.ypclients
* Tue Dec  4 2001 kukuk@suse.de
- If no YP_SERVER is set, print warning and use broadcast
* Tue Dec  4 2001 kukuk@suse.de
- Remove START variable
- Check, if portmapper is already running
- Add variable for additional ypbind parameters
* Tue Oct 30 2001 kukuk@suse.de
- Update to ypbind-mt 1.10 (locale fixes)
* Mon Oct 29 2001 kukuk@suse.de
- Update to ypbind-mt 1.9 (major bug fixes in thread and signal
  handling)
* Tue Sep 25 2001 ro@suse.de
- preserve permissions in SuSEconfig.ypclient
* Tue Aug 14 2001 kukuk@suse.de
- Fix some race conditions in ypbind-mt
- Fix setlocale() call
* Tue Jul 31 2001 kukuk@suse.de
- Also add a "+" to /etc/shadow if somebody really uses shadow over NIS
* Thu Apr 12 2001 kukuk@suse.de
- Remove configure patch to work with new gettext
* Thu Mar 22 2001 ro@suse.de
- added split-aliases as provides
* Wed Mar 21 2001 kukuk@suse.de
- Update to ypbind-mt-1.8
* Wed Jan 24 2001 kukuk@suse.de
- Provide ypclient
* Thu Nov 30 2000 kukuk@suse.de
- skip start of ypbind if not configured, don't die silently
* Thu Nov 30 2000 ro@suse.de
- startscript from sbin to etc
* Fri Nov 24 2000 kukuk@suse.de
- New, reworked init script
- Some more bug fixes
* Wed Nov 22 2000 kukuk@suse.de
- ypbind must be stopped before portmap
* Tue Nov 21 2000 kukuk@suse.de
- Use new init script
* Thu Nov  2 2000 kukuk@suse.de
- New version, split from ypclient
